﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.ComponentModel.Composition;
using System.Windows;
using MoNo;
using MoNo.Studio;
using MoNo.CSharpUtils;

namespace QuickCsTemplate
{
  [Export( typeof( MoNo.Studio.IMenuFactory ) )]
  class MessageMenuFactory : MenuFactoryForCSharp<QuickAppContext>
  {
    public override IEnumerable<MenuItem> EnumerateMenuItems( QuickAppContext con )
    {
      yield return MenuItemFactory.Folder( "Samples",
        MenuItemFactory.Folder( "MessageBox Samples",

          // ViewModel 側で直接メッセージボックスを表示するコードは書けないため、Messenger 機能を利用して View 側にメッセージを送信

          con.Messenger.Send( new MoNo.Wpf.InformationMessage( "Hello World", "InformationMessage" ) )
          .ToWpfCommand( con )
          .ToMenuItem( "InformationMessage" ),

          con.Messenger.Send( new MoNo.Wpf.OKCancelMessage( "OK? or Cancel?", "OKCancelMessage", MessageBoxImage.Exclamation ) )
          .ContinueWith( ok => con.Messenger.Send( new MoNo.Wpf.InformationMessage( ok ? "OK clicked" : "Cancel clicked", "InformationMessage" ) ) )
          .ToWpfCommand( con )
          .ToMenuItem( "OKCancelMessage" ),

          con.Messenger.Send( new MoNo.Wpf.YesNoCancelMessage( "Yes/No? or Cancel?", "YesNoCancelMessage", MessageBoxImage.Question ) )
          .ContinueWith( result =>
          {
            var response = result.Map( yes => yes ? "Yes clicked" : "No clicked" ).GetOr( "Cancel clicked" );
            return con.Messenger.Send( new MoNo.Wpf.InformationMessage( response, "response" ) );
          } )
          .ToWpfCommand( con )
          .ToMenuItem( "YesNoCancelMessage" ),


          // Messenger の機能をラップした ShowMesssage/GetOKCancel/GetYesNoCancel で簡単にメッセージ表示

          con.ShowMessage( "Hello ShowMessage" )
          .ToWpfCommand( con )
          .ToMenuItem( "ShowMessage" ),

          con.ShowOKCancelDialog( "OK? or Cancel?" )
          .ContinueWith( ok => con.ShowMessage( ok ? "OK clicked" : "Cancel clicked" ) )
          .ToWpfCommand( con )
          .ToMenuItem( "GetOKCancel" ),

          con.ShowYesNoCancelDialog( "Yes/No? or Cancel?" )
          .ContinueWith( result =>
            con.ShowMessage( result.Map( yes => yes ? "Yes clicked" : "No clicked" ).GetOr( "Cancel clicked" ) ) )
          .ToWpfCommand( con )
          .ToMenuItem( "GetYesNoCancel" )
        ) );
    }
  }
}
