﻿namespace QuickTemplate
open System
open System.ComponentModel.Composition
open System.Windows
open MoNo
open MoNo.Geometries
open MoNo.Studio


type [<Export (typeof<Studio.IMenuFactory>)>] private EntityMenuFactory() =
  inherit Studio.MenuFactory<QuickAppContext>()

  override __.CreateMenuItems con =
    let items =
      [
        MenuItem.New ("Polyline3d (= Polyline<Point3d>)",
          cont {
            // MoNo.Geometries.Polyline<Point3d> エンティティを生成
            let polyline =
              [| Point3d( 0.0, 0.0, 0.0 )
                 Point3d( 1.0, 0.0, 0.0 )
                 Point3d( 1.0, 1.0, 0.0 )
                 Point3d( 0.0, 1.0, 1.0 ) |] |> Polyline.ofArray false

            // シーングラフにエントリを登録
            con.Document.Val.Entries.Add (Wpf.Entry polyline)
          } |> Wpf.Cont.toWpfCommand con None)

        MenuItem.New ("Tris3d (= Soup<Triangle3d>)",
          cont {
            let tris = Tris3d ([| Triangle3d( Point3d( 0.0, 0.1, 0.3 ), Point3d( 0.2, 0.0, 0.5 ), Point3d( 0.4, 0.3, 0.0 ) )
                                  Triangle3d( Point3d( 0.8, 0.5, 0.4 ), Point3d( 0.0, 0.2, 0.4 ), Point3d( 0.2, 0.1, 0.6 ) )
                                  Triangle3d( Point3d( 0.8, 0.6, 0.3 ), Point3d( 0.3, 0.5, 0.4 ), Point3d( 0.2, 0.2, 0.0 ) )
                                  Triangle3d( Point3d( 0.5, 0.2, 0.5 ), Point3d( 0.3, 0.6, 0.1 ), Point3d( 0.0, 0.3, 0.7 ) ) |])
            con.Document.Val.Entries.Add (Wpf.Entry tris)
          } |> Wpf.Cont.toWpfCommand con None)

        MenuItem.New ("Mesh3d (= Mesh<Point3d>)",
          cont {
            let mesh =
              let vertices = // 頂点配列
                [| Point3d( 0.0, 0.0, 1.0 )
                   Point3d( 1.0, 0.0, 1.0 )
                   Point3d( 1.0, 1.0, 1.0 )
                   Point3d( 0.0, 1.0, 1.0 ) |]
              Mesh3d (vertices, [| Facet (0, 1, 2); Facet (0, 2, 3) |])
            con.Document.Val.Entries.Add (Wpf.Entry mesh)
          } |> Wpf.Cont.toWpfCommand con None)
      ]
    [ MenuItem.Folder ("Samples", [ MenuItem.Folder ("Entity Samples", items) ]) ]


